

class Cog:
    def __init__(self):
        self.commands = []

    def command(self, name):
        def decorator(fn):
            new_command = {
                'execute': fn,
                'name': name
            }
            def wrapper(ctx):
                fn(ctx)
            self.commands.append(new_command)
            return wrapper
        return decorator



from async_vk_lib.cog import Cog

cog = Cog()

class Example_data_class():
    def __init__(self):
        self.text = 'asdasdasd'

cla = Example_data_class()

@cog.command(name = 'asd')
async def test(ctx):
    print(cla.text)


def setup(bot):
    bot.add_cog(cog)



from io import open
from setuptools import setup

"""
:author: Yoko
:copyright: (c) 2021 Yoko
"""

version = '1.0.15'

long_description = '''Python lib for async requests to VK API with wait_for and cogs'''

setup(
    name='VK_async',
    version=version,

    author='Yoko',
    author_email='zartem01@gmail.ru',

    description=(
        u'Python module for writing bots for VK'
        u'(VK API wrapper)'
    ),
    long_description=long_description,
    # long_description_content_type='text/markdown',

    url='https://github.com/Yoko-0/VK_async',
    download_url='https://github.com/Yoko-0/VK_async.git',

    packages=['VK_async'],
    install_requires=['aiohttp', 'asyncio'],

    classifiers=[
        'Operating System :: OS Independent',
        'Intended Audience :: End Users/Desktop',
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Programming Language :: Python :: Implementation :: CPython',
    ]
)




from async_vk_lib.async_vk import Async_vk
import asyncio
import os


token = 'TOKEN'
group_id = GROUP_ID
bot = Async_vk(token)

for dir in os.listdir('./cogs'):
    if 'index.py' in os.listdir(f'./cogs/{dir}'):
        bot.load_extension(f'cogs.{dir}.index')

@bot.command(name = 'test')
async def test(ctx):
    await ctx.bot.send(ctx.message.user_id, 'Дадова ебать, жду от тебя "привет"')
    user_id = ctx.message.user_id

    def check(ctx):
        return user_id == ctx.message.user_id and ctx.message.text == 'привет'

    try:
        ctx = await ctx.bot.wait_for(check, timeout = 10)
        await ctx.bot.send(ctx.message.user_id, 'получил привет')

    except asyncio.TimeoutError:
        await ctx.bot.send(ctx.message.user_id, 'не дождался привет')


@bot.command(name = 'print')
async def test_print(ctx):
    print('print print')

@bot.command(name = 'hello')
async def test_hello(ctx):
    cmd = ctx.bot.get_command('hello')
    await cmd(ctx)
    print(ctx)


bot.run_bot(group_id)
